==> anywhereSSL_0.3.0.zip: anywhereSSL/language/english/anywheressl.php <==
<?php
//  ------------------------------------------------------------------------//
//  naming rule - prefix -                                                  //
//  _MD_ --- main.php       for contents                                    //
//  _MB_ --- blocks.php     for blocks                                      //
//  _AM_ --- admin.php      for admin                                       //
//  _MI_ --- modinfo.php    for xoops_version.php                           //
//  ------------------------------------------------------------------------//

if( ! defined( 'AWSSL_MOD_NAME' ) ) {

	define( 'AWSSL_MOD_NAME', 'Anywhere SSL' );

	define( 'AWSSL_TITLE', 'Item name' );
	define( 'AWSSL_DESCRIPTION', 'Description' );
	define( 'AWSSL_VALUE', 'Value' );

	define( 'AWSSL_SSL_URL', 'XOOPS_URL with SSL' );
	define( 'AWSSL_NON_SSL_URL', 'XOOPS_URL with non-SSL' );
	define( 'AWSSL_SESSION_NAME', 'The session name which is used the case of change between SSL and non-SSL' );
	define( 'AWSSL_REGENERATE_SID', 'Regenerate of session ID' );


	define( 'AWSSL_NONE', 'None' );
	define( 'AWSSL_INSERT', 'Regist' );
	define( 'AWSSL_UPDATE', 'Update' );
	define( 'AWSSL_DELETE', 'Delete' );

	define( 'AWSSL_YES', 'Yes' );
	define( 'AWSSL_NO', 'No' );

	define( 'AWSSL_COPMLETE_DATA_UPDATE', 'Update of the database completed.' );

	// error messages
	define( 'AWSSL_ERR_FAILED_DB_UPDATE', 'It failed in update of the database.' );
	define( 'AWSSL_ERR_FAILED_DESTINE', 'It failed in change between SSL and non-SSL.<br />One time please access several minutes later already.' );
	define( 'AWSSL_ERR_ILLEGITIMATE_OP', 'It is illegitimate operation.' );
	define( 'MYCSSADMIN_ERR_VALUE_TOO_LONG', 'As for value please make within %s byte.' );

	// warning messages

	// notice messages

}

?>

==> anywhereSSL_0.3.4.zip: anywhereSSL/language/english/anywheressl.php <==
<?php
//  ------------------------------------------------------------------------//
//  naming rule - prefix -                                                  //
//  _MD_ --- main.php       for contents                                    //
//  _MB_ --- blocks.php     for blocks                                      //
//  _AM_ --- admin.php      for admin                                       //
//  _MI_ --- modinfo.php    for xoops_version.php                           //
//  ------------------------------------------------------------------------//

if( ! defined( 'AWSSL_MOD_NAME' ) ) {

	define( 'AWSSL_MOD_NAME', 'Anywhere SSL' );

	define( 'AWSSL_TITLE', 'Item name' );
	define( 'AWSSL_DESCRIPTION', 'Description' );
	define( 'AWSSL_VALUE', 'Value' );

	define( 'AWSSL_SSL_URL', 'XOOPS_URL with SSL' );
	define( 'AWSSL_NON_SSL_URL', 'XOOPS_URL with non SSL' );
	define( 'AWSSL_SESSION_NAME', 'The session name which is used the case of change between SSL and non SSL' );
	define( 'AWSSL_REGENERATE_SID', 'Regenerate of session ID' );


	define( 'AWSSL_NONE', 'None' );
	define( 'AWSSL_INSERT', 'Regist' );
	define( 'AWSSL_UPDATE', 'Update' );
	define( 'AWSSL_DELETE', 'Delete' );

	define( 'AWSSL_YES', 'Yes' );
	define( 'AWSSL_NO', 'No' );

	define( 'AWSSL_COPMLETE_DATA_UPDATE', 'Update of the database completed.' );

	// error messages
	define( 'AWSSL_ERR_FAILED_DB_UPDATE', 'It failed in update of the database.' );
	define( 'AWSSL_ERR_FAILED_DESTINE', 'It failed in change between SSL and non SSL.<br />One time please access several minutes later already.' );
	define( 'AWSSL_ERR_CANNOT_DESTINE', 'In this page, it cannot change between SSL and non SSL.' );
	define( 'AWSSL_ERR_ILLEGITIMATE_OP', 'It is illegitimate operation.' );
	define( 'MYCSSADMIN_ERR_VALUE_TOO_LONG', 'As for value please make within %s byte.' );

	// warning messages

	// notice messages

}

?>
